@@ -18,7 +18,6 @@
     ObjectEntries,
     ObjectSetPrototypeOf,
     SymbolFor,
-    SymbolToStringTag,
   } = window.__bootstrap.primordials;
   const webidl = window.__bootstrap.webidl;
   const consoleInternal = window.__bootstrap.console;
@@ -120,10 +119,6 @@
       return this.#code;
     }
 
-    get [SymbolToStringTag]() {
-      return "DOMException";
-    }
-
     [SymbolFor("Deno.customInspect")](inspect) {
       if (this instanceof DOMException) {
         return `DOMException: ${this.#message}`;
