@@ -20,7 +20,6 @@
     PromiseResolve,
     StringPrototypeCharCodeAt,
     StringPrototypeSlice,
-    SymbolToStringTag,
     TypedArrayPrototypeSubarray,
     TypedArrayPrototypeSlice,
     Uint8Array,
@@ -126,10 +125,6 @@
         }
       }
     }
-
-    get [SymbolToStringTag]() {
-      return "TextDecoder";
-    }
   }
 
   webidl.configurePrototype(TextDecoder);
@@ -182,10 +177,6 @@
       });
       return core.opSync("op_encoding_encode_into", source, destination);
     }
-
-    get [SymbolToStringTag]() {
-      return "TextEncoder";
-    }
   }
 
   webidl.configurePrototype(TextEncoder);
@@ -272,10 +263,6 @@
       webidl.assertBranded(this, TextDecoderStream);
       return this.#transform.writable;
     }
-
-    get [SymbolToStringTag]() {
-      return "TextDecoderStream";
-    }
   }
 
   webidl.configurePrototype(TextDecoderStream);
@@ -345,10 +332,6 @@
       webidl.assertBranded(this, TextEncoderStream);
       return this.#transform.writable;
     }
-
-    get [SymbolToStringTag]() {
-      return "TextEncoderStream";
-    }
   }
 
   webidl.configurePrototype(TextEncoderStream);
